{% extends parent %}
{% block title %}{{ page.page_title }}{% endblock %}
{% block meta_description %}{{ page.meta_description }}{% endblock %}
{% block meta_keywords %}{{ page.meta_keywords }}{% endblock %}
{% block content %}
        {% block prehead %}{% endblock %}
        {% block header %}
            <header class="twelve columns alpha omega ">
                <h1>{{ page.title }}</h1>
            </header>
        {% endblock %}
        {% block posthead %}{% endblock %}
        {% block body %}
            <div class="twelve columns alpha omega page">
                {{ page.body|safe }}
            </div>
        {% endblock %}
        {% block postbody %}{% endblock %}
{% endblock %}